==> qttranslations-opensource-src_5.7.1~20161021.orig.tar.xz: qttranslations-opensource-src-5.7.1/translations/qtwebengine_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Authentifizierung erforderlich</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>&amp;Log In</source>
        <translation>&amp;Anmelden</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Follow Link</source>
        <translation>Link folgen</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Auswahl aufheben</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Link speichern</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Adresse des Bildes kopieren</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Bild kopieren</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Adresse des Medieninhalts kopieren</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Medieninhalt speichern</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Abspielen/Pausieren umschalten</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Wiederholung umschalten</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Stummschaltung umschalten</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Steuerelemente für Medieninhalte umschalten</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Element untersuchen</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Vollbildmodus verlassen</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig machen</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
    <message>
        <source>Paste and Match Style</source>
        <translation>Einfügen und Stil anpassen</translation>
    </message>
    <message>
        <source>Open Link in This Window</source>
        <translation>Link in diesem Fenster öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Window</source>
        <translation>Link in neuem Fenster öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Link in neuem Reiter öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Background Tab</source>
        <translation>Link in neuem Reiter im Hintergrund öffnen</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Link speichern</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Bild kopieren</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Adresse des Bildes kopieren</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Adresse des Medieninhalts kopieren</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Steuerelemente für Medieninhalte umschalten</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Wiederholung umschalten</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Abspielen/Pausieren umschalten</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Stummschaltung umschalten</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Medieninhalt speichern</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Element untersuchen</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Vollbildmodus verlassen</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Seite schließen</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Auswahl aufheben</translation>
    </message>
    <message>
        <source>Save &amp;Page</source>
        <translation>Seite s&amp;peichern</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Möchten Sie diese Seite wirklich verlassen?</translation>
    </message>
    <message>
        <source>Follow Link</source>
        <translation>Link folgen</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zurück</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Vorwärts</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Neu laden</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Verzeichnis zum Hochladen</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Javascript-Warnung - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Javascript-Bestätigung - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Javascript-Abfrage - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Möchten Sie diese Seite wirklich verlassen?</translation>
    </message>
</context>
<context>
    <name>QtWebEngineExperimentalPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineViewExperimental</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineViewExperimental erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineViewport</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineViewport erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineContextMenuData</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineContextMenuData erstellt werden</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create separate instance of WebEngineLoadRequest</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineLoadRequest erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNavigationRequest</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineNavigationRequest erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineCertificateError</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineCertificateError erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineDownloadItem erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineNewViewRequest erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineSettings</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineSettings erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Es kann keine separate Instanz der Klasse NavigationHistory erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Es kann keine separate Instanz der Klasse FullScreenRequest erstellt werden</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineErrorPage erstellt werden</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Verbinde zu Proxy &quot;%1&quot; unter Verwendung von:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>Geben Sie Nutzername und Passwort für &quot;%1&quot; auf %2://%3 ein</translation>
    </message>
</context>
</TS>

==> qttranslations-opensource-src_5.9.5.orig.tar.xz: qttranslations-opensource-src-5.9.5/translations/qtwebengine_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>DownloadInterruptReason</name>
    <message>
        <source>Unknown reason or not interrupted</source>
        <translation>Unbekannte Ursache oder es liegt keine Unterbrechung vor</translation>
    </message>
    <message>
        <source>General file operation failure</source>
        <translation>Genereller Fehler bei Dateioperation</translation>
    </message>
    <message>
        <source>The file cannot be written locally, due to access restrictions</source>
        <translation>Die Datei kann auf Grund fehlender Zugriffsrechte nicht lokal geschrieben werden</translation>
    </message>
    <message>
        <source>Insufficient space on the target drive</source>
        <translation>Unzureichender Speicherplatz auf dem Ziellaufwerk</translation>
    </message>
    <message>
        <source>The directory or file name is too long</source>
        <translation>Der Name des Verzeichnisses oder der Datei ist zu lang</translation>
    </message>
    <message>
        <source>The file size exceeds the file system limitation</source>
        <translation>Die Dateigröße überschreitet die Höchstgröße des Dateisystems</translation>
    </message>
    <message>
        <source>The file is infected with a virus</source>
        <translation>Die Datei ist mit einem Virus infiziert</translation>
    </message>
    <message>
        <source>Temporary problem (for example file in use, or too many open files)</source>
        <translation>Temporäres Problem (zum Beispiel könnte die Datei gerade in Benutzung sein, oder es sind zu viele Dateien geöffnet)</translation>
    </message>
    <message>
        <source>The file was blocked due to local policy</source>
        <translation>Die Datei wurde durch eine lokale Richtlinie gesperrt</translation>
    </message>
    <message>
        <source>Checking the safety of the download failed due to unexpected reasons</source>
        <translation>Die Sicherheitsüberprüfung der heruntergeladenen Datei schlug aus unerwarteten Gründen fehl</translation>
    </message>
    <message>
        <source>File seek past the end of a file (resuming previously interrupted download)</source>
        <translation>Dateisuchoperation ging über das Dateiende hinaus (bei der Fortsetzung eines zuvor unterbrochenen Downloads)</translation>
    </message>
    <message>
        <source>The partial file did not match the expected hash</source>
        <translation>Der Teil der Datei entspricht nicht dem erwarteten Hashwert</translation>
    </message>
    <message>
        <source>General network failure</source>
        <translation>Genereller Netzwerkfehler</translation>
    </message>
    <message>
        <source>The network operation has timed out</source>
        <translation>Zeitüberschreitung bei Netzwerkoperation</translation>
    </message>
    <message>
        <source>The network connection has been terminated</source>
        <translation>Die Netzwerkverbindung wurde beendet</translation>
    </message>
    <message>
        <source>The server has gone down</source>
        <translation>Der Server wurde gestoppt</translation>
    </message>
    <message>
        <source>The network request was invalid (for example, the URL or scheme is invalid)</source>
        <translation>Die Netzwerkanforderung war ungültig (zum Beispiel könnten URL oder Schema ungültig gewesen sein)</translation>
    </message>
    <message>
        <source>General server failure</source>
        <translation>Genereller Serverfehler</translation>
    </message>
    <message>
        <source>The server does not have the requested data</source>
        <translation>Der Server hat die angeforderten Daten nicht</translation>
    </message>
    <message>
        <source>The server did not authorize access to the resource</source>
        <translation>Der Server hat den Zugriff auf die Ressource nicht zugelassen</translation>
    </message>
    <message>
        <source>A problem with the server certificate occurred</source>
        <translation>Es ist ein Problem mit dem Serverzertifikat aufgetreten</translation>
    </message>
    <message>
        <source>Access forbidden by the server</source>
        <translation>Der Server gestattet den Zugriff nicht</translation>
    </message>
    <message>
        <source>Unexpected server response</source>
        <translation>Der Server lieferte eine unerwartete Antwort</translation>
    </message>
    <message>
        <source>Download canceled by the user</source>
        <translation>Herunterladen vom Nutzer abgebrochen</translation>
    </message>
</context>
<context>
    <name>MediaCaptureDevicesDispatcher</name>
    <message>
        <source>Do you want %1 to share your screen?</source>
        <translation>Möchten Sie den Inhalt Ihres Bildschirms mit %1 teilen?</translation>
    </message>
    <message>
        <source>%1 Screen Sharing request</source>
        <translation>%1 Anfrage zwecks Teilen des Bildschirminhalts</translation>
    </message>
</context>
<context>
    <name>QQuickWebEngineView</name>
    <message>
        <source>Follow Link</source>
        <translation>Link folgen</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>View Page Source</source>
        <translation>Seitenquelltext anzeigen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Auswahl aufheben</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Link speichern</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Adresse des Bildes kopieren</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Bild kopieren</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Adresse des Medieninhalts kopieren</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Medieninhalt speichern</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Abspielen/Pausieren umschalten</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Wiederholung umschalten</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Stummschaltung umschalten</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Steuerelemente für Medieninhalte umschalten</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Element untersuchen</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Vollbildmodus verlassen</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vorwärts</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation>Unter Umgehung des Caches neu laden</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig machen</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
    <message>
        <source>Paste and Match Style</source>
        <translation>Einfügen und Stil anpassen</translation>
    </message>
    <message>
        <source>Open Link in This Window</source>
        <translation>Link in diesem Fenster öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Window</source>
        <translation>Link in neuem Fenster öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Link in neuem Reiter öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Background Tab</source>
        <translation>Link in neuem Reiter im Hintergrund öffnen</translation>
    </message>
    <message>
        <source>Copy Link URL</source>
        <translation>Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Save Link</source>
        <translation>Link speichern</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Bild kopieren</translation>
    </message>
    <message>
        <source>Copy Image URL</source>
        <translation>Adresse des Bildes kopieren</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>Copy Media URL</source>
        <translation>Adresse des Medieninhalts kopieren</translation>
    </message>
    <message>
        <source>Toggle Media Controls</source>
        <translation>Steuerelemente für Medieninhalte umschalten</translation>
    </message>
    <message>
        <source>Toggle Looping</source>
        <translation>Wiederholung umschalten</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Abspielen/Pausieren umschalten</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Stummschaltung umschalten</translation>
    </message>
    <message>
        <source>Save Media</source>
        <translation>Medieninhalt speichern</translation>
    </message>
    <message>
        <source>Inspect Element</source>
        <translation>Element untersuchen</translation>
    </message>
    <message>
        <source>Exit Full Screen Mode</source>
        <translation>Vollbildmodus verlassen</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Seite schließen</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Auswahl aufheben</translation>
    </message>
    <message>
        <source>Save &amp;Page</source>
        <translation>Seite s&amp;peichern</translation>
    </message>
    <message>
        <source>&amp;View Page Source</source>
        <translation>Seiten&amp;quelltext anzeigen</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page? Changes that you made may not be saved.</source>
        <translation>Möchten Sie diese Seite wirklich verlassen? Von Ihnen vorgenommene Änderungen könnten verlorengehen.</translation>
    </message>
    <message>
        <source>Follow Link</source>
        <translation>Link folgen</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zurück</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Vorwärts</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Neu laden</translation>
    </message>
    <message>
        <source>Select folder to upload</source>
        <translation>Verzeichnis zum Hochladen</translation>
    </message>
</context>
<context>
    <name>QtWebEngineCore</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Javascript-Warnung - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Javascript-Bestätigung - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Javascript-Abfrage - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Möchten Sie diese Seite wirklich verlassen?</translation>
    </message>
    <message>
        <source>Changes that you made may not be saved.</source>
        <translation>Ihre ausstehenden Änderungen werden eventuell nicht gesichert.</translation>
    </message>
</context>
<context>
    <name>QtWebEnginePlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineDownloadItem</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineDownloadItem erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create separate instance of WebEngineNewViewRequest</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineNewViewRequest erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of WebEngineSettings</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineSettings erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of NavigationHistory</source>
        <translation>Es kann keine separate Instanz der Klasse NavigationHistory erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create a separate instance of FullScreenRequest</source>
        <translation>Es kann keine separate Instanz der Klasse FullScreenRequest erstellt werden</translation>
    </message>
    <message>
        <source>Cannot create separate instance of %1</source>
        <translation>Es kann keine separate Instanz der Klasse %1 erstellt werden</translation>
    </message>
</context>
<context>
    <name>QtWebEngineTestSupportPlugin</name>
    <message>
        <source>Cannot create a separate instance of WebEngineErrorPage</source>
        <translation>Es kann keine separate Instanz der Klasse WebEngineErrorPage erstellt werden</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Verbinde zu Proxy &quot;%1&quot; unter Verwendung von:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>Geben Sie Nutzername und Passwort für &quot;%1&quot; auf %2://%3 ein</translation>
    </message>
</context>
<context>
    <name>WebContentsAdapter</name>
    <message>
        <source>HTTP-POST data can only be sent over HTTP(S) protocol</source>
        <translation>HTTP-POST-Daten können nur mittels HTTP(S)-Protokoll versandt werden</translation>
    </message>
</context>
</TS>
